# sbcommons

Packages shared between different lambda functions

### 0.61 - Deprecated
- Added teams client

### 0.62

- Added parse_utils sub-module for parsing configuration files and other text files.
- Added an execute_query method to aws.redshift.RedshiftClient for performing select statements given a string parameter.
- Making teams into a utility class instead of a client

### 0.63
- Upgraded all the packages to python 3.9 packages

### 0.64
- Minor bug fixes to allow for package dependencies

### 0.65 - Deprecated
- Added the RotatingFileHandler class for time-rotating logging files.

### 0.66
- Fixed issue with RotatingFileHandler appending wrong suffixes to log file names.

### 0.67
- Added abstract class crm.client and made Klaviyo and Symplify clients inherit from it. 
- Changed typing import in parse_utils, importing OrderedDict instead of MutableMapping. 